==> com.liferay.journal.web-3.0.20.jar: META-INF/resources/js/ManagementToolbarDefaultEventHandler.es.js <==
"use strict";

Liferay.Loader.define("journal-web@3.0.20/js/ManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web/liferay/DefaultEventHandler.es', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = void 0;

  var _DefaultEventHandler2 = _interopRequireDefault(require("frontend-js-web/liferay/DefaultEventHandler.es"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var ManagementToolbarDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(ManagementToolbarDefaultEventHandler, _DefaultEventHandler);

    function ManagementToolbarDefaultEventHandler() {
      _classCallCheck(this, ManagementToolbarDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(ManagementToolbarDefaultEventHandler).apply(this, arguments));
    }

    _createClass(ManagementToolbarDefaultEventHandler, [{
      key: "created",
      value: function created() {
        var addArticleURL = this.addArticleURL;
        var namespace = this.namespace;
        Liferay.on(this.ns('selectAddMenuItem'), function (event) {
          var selectAddMenuItemWindow = Liferay.Util.Window.getById(namespace + 'selectAddMenuItem');
          selectAddMenuItemWindow.set('destroyOnHide', false);
          Liferay.fire('closeWindow', {
            id: namespace + 'selectAddMenuItem',
            redirect: Liferay.Util.addParams(namespace + 'ddmStructureKey=' + event.ddmStructureKey, addArticleURL)
          });
        });
      }
    }, {
      key: "deleteEntries",
      value: function deleteEntries() {
        var message = Liferay.Language.get('are-you-sure-you-want-to-delete-the-selected-entries');

        if (this.trashEnabled) {
          message = Liferay.Language.get('are-you-sure-you-want-to-move-the-selected-entries-to-the-recycle-bin');
        }

        if (confirm(message)) {
          Liferay.fire(this.ns('editEntry'), {
            action: this.trashEnabled ? 'moveEntriesToTrash' : 'deleteEntries'
          });
        }
      }
    }, {
      key: "expireEntries",
      value: function expireEntries() {
        Liferay.fire(this.ns('editEntry'), {
          action: 'expireEntries'
        });
      }
    }, {
      key: "handleCreationMenuMoreButtonClicked",
      value: function handleCreationMenuMoreButtonClicked(event) {
        event.preventDefault();
        Liferay.Util.openWindow({
          dialog: {
            after: {
              destroy: function destroy(event) {
                if (event.target.get('destroyOnHide')) {
                  window.location.reload();
                }
              }
            },
            destroyOnHide: true,
            modal: true
          },
          id: this.ns('selectAddMenuItem'),
          title: Liferay.Language.get('more'),
          uri: this.openViewMoreStructuresURL
        });
      }
    }, {
      key: "moveEntries",
      value: function moveEntries() {
        Liferay.fire(this.ns('editEntry'), {
          action: 'moveEntries'
        });
      }
    }, {
      key: "openDDMStructuresSelector",
      value: function openDDMStructuresSelector() {
        var namespace = this.namespace;
        var uri = this.viewDDMStructureArticlesURL;
        Liferay.Util.selectEntity({
          dialog: {
            constrain: true,
            modal: true
          },
          eventName: this.ns('selectDDMStructure'),
          title: Liferay.Language.get('structures'),
          uri: this.selectEntityURL
        }, function (event) {
          location.href = Liferay.Util.addParams(namespace + 'ddmStructureKey=' + event.ddmstructurekey, uri);
        });
      }
    }]);

    return ManagementToolbarDefaultEventHandler;
  }(_DefaultEventHandler2.default);

  ManagementToolbarDefaultEventHandler.STATE = {
    addArticleURL: _metalState.Config.string(),
    folderId: _metalState.Config.string(),
    namespace: _metalState.Config.string(),
    openViewMoreStructuresURL: _metalState.Config.string(),
    selectEntityURL: _metalState.Config.string(),
    trashEnabled: _metalState.Config.bool(),
    viewDDMStructureArticlesURL: _metalState.Config.string()
  };
  var _default = ManagementToolbarDefaultEventHandler;
  exports.default = _default;
  //# sourceMappingURL=ManagementToolbarDefaultEventHandler.es.js.map
});
//# sourceMappingURL=ManagementToolbarDefaultEventHandler.es.js.map

==> com.liferay.journal.web-3.0.48.jar: META-INF/resources/js/ManagementToolbarDefaultEventHandler.es.js <==
Liferay.Loader.define("journal-web@3.0.48/js/ManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  var _metalState = require("frontend-js-metal-web$metal-state");

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var ManagementToolbarDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(ManagementToolbarDefaultEventHandler, _DefaultEventHandler);

    function ManagementToolbarDefaultEventHandler() {
      _classCallCheck(this, ManagementToolbarDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(ManagementToolbarDefaultEventHandler).apply(this, arguments));
    }

    _createClass(ManagementToolbarDefaultEventHandler, [{
      key: "created",
      value: function created() {
        var addArticleURL = this.addArticleURL;
        var namespace = this.namespace;
        Liferay.on(this.ns('selectAddMenuItem'), function (event) {
          var selectAddMenuItemWindow = Liferay.Util.Window.getById(namespace + 'selectAddMenuItem');
          selectAddMenuItemWindow.set('destroyOnHide', false);
          Liferay.fire('closeWindow', {
            id: namespace + 'selectAddMenuItem',
            redirect: Liferay.Util.addParams(namespace + 'ddmStructureKey=' + event.ddmStructureKey, addArticleURL)
          });
        });
      }
    }, {
      key: "deleteEntries",
      value: function deleteEntries() {
        var message = Liferay.Language.get('are-you-sure-you-want-to-delete-the-selected-entries');

        if (this.trashEnabled) {
          message = Liferay.Language.get('are-you-sure-you-want-to-move-the-selected-entries-to-the-recycle-bin');
        }

        if (confirm(message)) {
          Liferay.fire(this.ns('editEntry'), {
            action: this.trashEnabled ? '/journal/move_entries_to_trash' : '/journal/delete_entries'
          });
        }
      }
    }, {
      key: "expireEntries",
      value: function expireEntries() {
        Liferay.fire(this.ns('editEntry'), {
          action: '/journal/expire_entries'
        });
      }
    }, {
      key: "handleCreationMenuMoreButtonClicked",
      value: function handleCreationMenuMoreButtonClicked(event) {
        event.preventDefault();
        Liferay.Util.openWindow({
          dialog: {
            after: {
              destroy: function destroy(event) {
                if (event.target.get('destroyOnHide')) {
                  window.location.reload();
                }
              }
            },
            destroyOnHide: true,
            modal: true
          },
          id: this.ns('selectAddMenuItem'),
          title: Liferay.Language.get('more'),
          uri: this.openViewMoreStructuresURL
        });
      }
    }, {
      key: "moveEntries",
      value: function moveEntries() {
        var moveEntriesURL = this.moveEntriesURL;
        var entrySelectorNodes = document.querySelectorAll('.entry-selector');
        entrySelectorNodes.forEach(function (node) {
          if (node.checked) {
            moveEntriesURL = Liferay.Util.addParams("".concat(node.name, "=").concat(node.value), moveEntriesURL);
          }
        });
        Liferay.Util.navigate(moveEntriesURL);
      }
    }, {
      key: "openDDMStructuresSelector",
      value: function openDDMStructuresSelector() {
        var namespace = this.namespace;
        var uri = this.viewDDMStructureArticlesURL;
        Liferay.Util.selectEntity({
          dialog: {
            constrain: true,
            modal: true
          },
          eventName: this.ns('selectDDMStructure'),
          title: Liferay.Language.get('structures'),
          uri: this.selectEntityURL
        }, function (event) {
          Liferay.Util.navigate(Liferay.Util.addParams(namespace + 'ddmStructureKey=' + event.ddmstructurekey, uri));
        });
      }
    }]);

    return ManagementToolbarDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  ManagementToolbarDefaultEventHandler.STATE = {
    addArticleURL: _metalState.Config.string(),
    folderId: _metalState.Config.string(),
    moveEntriesURL: _metalState.Config.string(),
    namespace: _metalState.Config.string(),
    openViewMoreStructuresURL: _metalState.Config.string(),
    selectEntityURL: _metalState.Config.string(),
    trashEnabled: _metalState.Config.bool(),
    viewDDMStructureArticlesURL: _metalState.Config.string()
  };
  var _default = ManagementToolbarDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=ManagementToolbarDefaultEventHandler.es.js.map
});
//# sourceMappingURL=ManagementToolbarDefaultEventHandler.es.js.map
